{ pkgs ? (import <nixpkgs> { })
, callPackage ? pkgs.callPackage
, stdenv ? pkgs.stdenv
, fetchgit ? pkgs.fetchgit
, name ? "brownpaper"
, src ? ./.
}:
let
  filteredSrc = src; # flake only includeds files tracked by git builtins.filterSource pkgs.lib.cleanSourceFilter src;
  crate2nix = fetchGit { url = "https://github.com/kolloch/crate2nix.git"; rev = "445c74fdbc7fe01694814b7bc349a89942c7d8a0"; };
  crate2nix_tools = (if builtins.compareVersions pkgs.crate2nix.version "0.8.0" == 1 then import (pkgs.crate2nix.src + "/tools.nix") else import "${crate2nix}/tools.nix") { inherit pkgs; };
  overrides = with pkgs.llvmPackages_10;
    pkgs.defaultCrateOverrides // rec {
      nettle-sys = attrs: rec {
        nativeBuildInputs = [ clang pkgs.pkg-config ];
        buildInputs = [ pkgs.nettle ];
        LIBCLANG_PATH = "${libclang}/lib";
      };
      brownpaper = attrs: {
        nativeBuildInputs = [ clang pkgs.pkg-config ];
        LIBCLANG_PATH = "${libclang}/lib";
        buildInputs = [ pkgs.gmp ];
      };
    };
  client = with pkgs; runCommandLocal "brownpaper"
    {
      script = "${filteredSrc}/bp.sh";
      nativeBuildInputs = [ makeWrapper ];
    } ''
    makeWrapper $script $out/bin/brownpaper \
    --prefix PATH : ${with pkgs; lib.makeBinPath [ bash curl gnupg ]}
  '';
in
{ server = (callPackage (crate2nix_tools.generatedCargoNix { inherit name; src = filteredSrc; }) { inherit pkgs; defaultCrateOverrides = overrides; }).rootCrate.build;  inherit client; }
